package com.srs.teacher.mapper;

import java.util.List;

import com.srs.teacher.domain.SysPerformanceActive;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import org.apache.ibatis.annotations.Param;

/**
 * 综合绩效-辅导员工作室Mapper接口
 *
 * @author srs
 * @date 2024-06-17
 */
public interface SysPerformanceActiveMapper extends BaseMapper<SysPerformanceActive> {
    /**
     * 查询综合绩效-辅导员工作室
     *
     * @param id 综合绩效-辅导员工作室主键
     * @return 综合绩效-辅导员工作室
     */
    public SysPerformanceActive selectSysPerformanceActiveById(Long id);

    /**
     * 查询综合绩效-辅导员工作室列表
     *
     * @param sysPerformanceActive 综合绩效-辅导员工作室
     * @return 综合绩效-辅导员工作室集合
     */
    List<SysPerformanceActive> selectSysPerformanceActiveList(SysPerformanceActive sysPerformanceActive);

//    根据填报人、月份查询
    public SysPerformanceActive selectSysPerformanceActiveByFdyName(@Param("fdName") String fdName, @Param("years") String years);
    /**
     * 新增综合绩效-辅导员工作室
     *
     * @param sysPerformanceActive 综合绩效-辅导员工作室
     * @return 结果
     */
    int insertSysPerformanceActive(SysPerformanceActive sysPerformanceActive);

    /**
     * 修改综合绩效-辅导员工作室
     *
     * @param sysPerformanceActive 综合绩效-辅导员工作室
     * @return 结果
     */
    int updateSysPerformanceActive(SysPerformanceActive sysPerformanceActive);

    /**
     * 删除综合绩效-辅导员工作室
     *
     * @param id 综合绩效-辅导员工作室主键
     * @return 结果
     */
    int deleteSysPerformanceActiveById(Long id);

    /**
     * 批量删除综合绩效-辅导员工作室
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteSysPerformanceActiveByIds(Long[] ids);
}
